@@ -101,10 +101,11 @@ Add methods to L<Mandel::Relationship/document_class>.
 sub monkey_patch {
   my $self          = shift;
   my $foreign_field = $self->foreign_field;
+  my $accessor      = $self->accessor;
 
   Mojo::Util::monkey_patch(
     $self->document_class,
-    $self->accessor,
+    $accessor,
     sub {
       my $cb                 = ref $_[-1] eq 'CODE' ? pop : undef;
       my $doc                = shift;
@@ -112,10 +113,10 @@ sub monkey_patch {
       my $related_model      = $self->_related_model;
       my $related_collection = $related_model->new_collection($doc->connection);
 
-      if ($obj) {    # set ===========================================================
+      if ($obj) {    # set
         if (UNIVERSAL::isa($obj, 'Mango::BSON::ObjectID')) {
           $doc->data->{$foreign_field} = bson_dbref $related_model->collection_name, $obj;
-          return $doc;
+          return $obj;
         }
         if (ref $obj eq 'HASH') {
           $obj = $related_collection->create($obj);
@@ -127,7 +128,8 @@ sub monkey_patch {
         unless ($cb) {
           $obj->save;
           $doc->save;
-          return $doc;
+          $doc->_cache($accessor => $obj);
+          return $obj;
         }
 
         # Non-blocking
@@ -140,14 +142,25 @@ sub monkey_patch {
           sub {
             my ($delay, $o_err, $d_err) = @_;
             my $err = $o_err || $d_err;
+            $doc->_cache($accessor => $obj) unless $err;
             $doc->$cb($err, $obj);
           },
         );
       }
-      else {    # get =============================================================
+      elsif (!delete $doc->{fresh} and my $cached = $doc->_cache($accessor)) {    # get cached
+        return $cached unless $cb;
+        $self->$cb('', $cached);
+      }
+      else {                                                                      # get
         my $cursor = $related_collection->search({_id => $doc->data->{$foreign_field}{'$id'}});
-        return $cursor->single unless $cb;
-        $cursor->single(sub { $doc->$cb(@_[1, 2]) });
+        return $doc->_cache($accessor => $cursor->single) unless $cb;
+        $cursor->single(
+          sub {
+            my ($cursor, $err, $obj) = @_;
+            $doc->_cache($accessor => $obj) unless $err;
+            $doc->$cb($err, $obj);
+          }
+        );
       }
 
       $doc;
